Releases
========


`1.0.1 <https://github.com/Perceptua/indexia/releases/tag/v1.0.1>`_
-------------------------------------------------------------------

**Features:**

* Improve README & add link to Read the Docs.

**Bugfixes:**

* Fix broken documentation links by relocating README contents.

`1.0.0 <https://github.com/Perceptua/indexia/releases/tag/v1.0.0>`_
-------------------------------------------------------------------

**Features:**

* Version 1.0.0 will constitute first post-beta version.

**Bugfixes:**

* Make README links PYPI-friendly.


`0.0.5 <https://github.com/Perceptua/indexia/releases/tag/v0.0.5>`_
-------------------------------------------------------------------

**Features:**

* Update documentation layout, expand on usage & applications.
* Add glossary of ``indexia`` terms.
* ``schemata.Corpus``: Enable creation of multi-creator corpus dataframes.

**Bugfixes:**

* Update variable names in ``schemata.Dendron`` to align with other classes.
* Update variable names in ``inquiry.Tabula`` to align with other classes.


`0.0.4 <https://github.com/Perceptua/indexia/releases/tag/v0.0.4>`_
-------------------------------------------------------------------

**Features:**

* Add ``.readthedocs.yaml`` to configure Read the Docs documentation.

**Bugfixes:**

* Fix Read the Docs import error in ``docs/source/conf.py``.


`0.0.3 <https://github.com/Perceptua/indexia/releases/tag/v0.0.3>`_
-------------------------------------------------------------------

**Bugfixes:**

* Fix ``README.rst`` codeblocks & reconfigure ``pyproject.toml`` for first PYPI release.


`0.0.2 <https://github.com/Perceptua/indexia/releases/tag/v0.0.2>`_
-------------------------------------------------------------------

**Features:**

* Add 'zettelkasten' template to ``indexia.eidola.Templates``.


`0.0.1 <https://github.com/Perceptua/indexia/releases/tag/v0.0.1>`_
-------------------------------------------------------------------

**Features:**

* ``eidola.Templates`` class to create sample data.


`0.0.0 <https://github.com/Perceptua/indexia/releases/tag/v0.0.0>`_
-------------------------------------------------------------------

**Features:**

* ``indexia`` module to create & manage hierarchical data structures.
* ``inquiry`` module to support dynamic SQL generation.
* ``schemata`` module to create XML, dataframe, & network graph representations of indexia data.
* ``eidola`` module to create sample indexia data.